#!/bin/bash
#
# TeamCall CA Innovaphone (Linux)
# linux-installer.sh
#
# Copyright (c) 2024-2025 by ilink Kommunikationssysteme GmbH.  All Rights Reserved.
#
# This script will call the Java based command line installer for CA Innovaphone
#
# Requirements:
# - The calling user must have root permissions.
# - java needs to be on the search path.
#


PATH=$PATH:/usr/bin:/usr/sbin:/sbin


# Check folder
if [ ! -f "linux-installer.sh" ]; then
	echo ""
	echo "You are not in the correct folder."
	echo "Please change to the installer folder."
	echo "Installation cancelled"
	echo ""
	exit 1
fi

# Check for root permissions
perm=$(id -u)
if [ "$perm" != "0" ]; then
	echo ""
	echo "You must have root permissions to start the installer."
	echo "Installation cancelled"
	echo ""
	exit 1
fi


# Default values of CA config parameters
INNOAPP_URL="wss://ipva.server.com/PBX0/APPS/websocket"
INNOAPP_NAME="TeamCall"
INNOAPP_PWD="secret"
SERVICE_PORT="26002"
SERVICE_SUFFIX="1"

INSTALLCONFIG="auto-install.xml"            # File name of the install config file
INSTALLERFILE="ca_innovaphone_install*.jar" # File name of the Izpack install pkg (this variable may not be used within quotes)
INSTALLLOGFILE="CAInnovaphone-install.log"  # File name of the install log file
INSTALLPATH="/usr/local/ilink/CA Innovaphone"


# Variables install script
#DEBUGOPTION="-DDEBUG=true -DTRACE=true -DSTACKTRACE=true"
DEBUGOPTION="-DTRACE=true -DSTACKTRACE=true"
checkParameter="0"



  echo; echo "Starting CA Innovaphone Linux install script"
( echo; echo "Starting CA Innovaphone Linux install script" ) > "$INSTALLLOGFILE"


#================================================================
# Read and confirm all parameters
#================================================================

while [ "$checkParameter" != "OK" ]
do
	echo ""

	echo -e "Innovaphone App URL [$INNOAPP_URL]:\c "
	read INNOAPP_URL_TMP

	if [ "$INNOAPP_URL_TMP" != "" ]; then
		INNOAPP_URL="$INNOAPP_URL_TMP"
	fi

	echo -e "Innovaphone App name [$INNOAPP_NAME]:\c "
	read INNOAPP_NAME_TMP

	if [ "$INNOAPP_NAME_TMP" != "" ]; then
		INNOAPP_NAME="$INNOAPP_NAME_TMP"
	fi

	echo -e "Innovaphone App password [$INNOAPP_PWD]:\c "
	read INNOAPP_PWD_TMP

	if [ "$INNOAPP_PWD_TMP" != "" ]; then
		INNOAPP_PWD="$INNOAPP_PWD_TMP"
	fi

	echo -e "CA service port [$SERVICE_PORT]:\c "
	read SERVICE_PORT_TMP

	if [ "$SERVICE_PORT_TMP" != "" ]; then
		SERVICE_PORT="$SERVICE_PORT_TMP"
	fi

	echo -e "CA node suffix [$SERVICE_SUFFIX]:\c "
	read SERVICE_SUFFIX_TMP

	if [ "$SERVICE_SUFFIX_TMP" != "" ]; then
		SERVICE_SUFFIX="$SERVICE_SUFFIX_TMP"
	fi

	echo -e "CA installation path [$INSTALLPATH]:\c "
	read INSTALLPATH_TMP

	if [ "$INSTALLPATH_TMP" != "" ]; then
		INSTALLPATH="$INSTALLPATH_TMP"
	fi

	echo ""
	echo "---------------------------------------------"
	echo "          Check our settings!"
	echo ""
	echo " Innovaphone App URL:      $INNOAPP_URL"
	echo " Innovaphone App name:     $INNOAPP_NAME"
	echo " Innovaphone App password: $INNOAPP_PWD"
	echo " CA service port:          $SERVICE_PORT"
	echo " CA node suffix:           $SERVICE_SUFFIX"
	echo " CA installation path:     $INSTALLPATH"
	echo ""
	echo "---------------------------------------------"

	checker="0"
	echo -e "Are these settings correct? Then type OK: \c"
	read checker

	if [ "$checker" == "OK" ]; then
		checkParameter="OK"
	fi
done

(
	echo ""
	echo "----------------------------------------------------------------"
	echo " Using these settings:"
	echo ""
	echo " Innovaphone App URL:      $INNOAPP_URL"
	echo " Innovaphone App name:     $INNOAPP_NAME"
	echo " Innovaphone App password: $INNOAPP_PWD"
	echo " CA service port:          $SERVICE_PORT"
	echo " CA node suffix:           $SERVICE_SUFFIX"
	echo " CA installation path:     $INSTALLPATH"
	echo ""
	echo "----------------------------------------------------------------"
) >> "$INSTALLLOGFILE"



# Create a configuration file for automatic installation
  echo; echo; echo "Creating configuration file $INSTALLCONFIG:"
( echo; echo; echo "Creating configuration file $INSTALLCONFIG" ) >> "$INSTALLLOGFILE"

cat > "$INSTALLCONFIG" << EOF
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<AutomatedInstallation langpack="eng">
	<com.izforge.izpack.panels.hello.HelloPanel id="HelloPanel_0" />
	<com.izforge.izpack.panels.userinput.UserInputPanel id="UserInput.panel">
		<entry key="SERVER_PORT" value="$SERVICE_PORT" />
		<entry key="INNOAPP_URL" value="$INNOAPP_URL" />
		<entry key="INNOAPP_NAME" value="$INNOAPP_NAME" />
		<entry key="INNOAPP_PWD" value="$INNOAPP_PWD" />
		<entry key="SERVICE_SUFFIX" value="$SERVICE_SUFFIX" />
	</com.izforge.izpack.panels.userinput.UserInputPanel>
	<com.izforge.izpack.panels.target.TargetPanel id="TargetPanel_2">
		<installpath>$INSTALLPATH</installpath>
	</com.izforge.izpack.panels.target.TargetPanel>
	<com.izforge.izpack.panels.install.InstallPanel id="InstallPanel_3" />
	<com.izforge.izpack.panels.finish.FinishPanel id="FinishPanel_4" />
</AutomatedInstallation>

EOF

(
	echo "----------------------------------------------------------------"
	cat $INSTALLCONFIG
	echo "----------------------------------------------------------------"
) >> "$INSTALLLOGFILE"



# Delete previous installation
  echo; echo; echo "Deleting previous installation"
( echo; echo; echo "Deleting previous installation" ) >> "$INSTALLLOGFILE"

rm -rf "$INSTALLPATH"
rm -rf /etc/init.d/CAInnovaphone_*
if [ -e /etc/rc0.d ]; then
	rm -rf /etc/rc*.d/K01CAInnovaphone_*
	rm -rf /etc/rc*.d/S02CAInnovaphone_*
elif [ -e /etc/init.d/rc0.d ]; then
	rm -rf /etc/init.d/rc*.d/K01CAInnovaphone_*
	rm -rf /etc/init.d/rc*.d/S02CAInnovaphone_*
fi



# Start the IzPack installer, using the automatic installation configuration data generated above
# - java needs to be on the search path.
  echo; echo; echo "Starting CA Innovaphone installer"
( echo; echo; echo "Starting CA Innovaphone installer" ) >> "$INSTALLLOGFILE"

JAVA=java
  echo; echo "> $JAVA $DEBUGOPTION -jar $INSTALLERFILE -defaults-file \"$INSTALLCONFIG\""
( echo; echo "> $JAVA $DEBUGOPTION -jar $INSTALLERFILE -defaults-file \"$INSTALLCONFIG\"" ) >> "$INSTALLLOGFILE"
$JAVA $DEBUGOPTION -jar $INSTALLERFILE "$INSTALLCONFIG" 2>&1 | tee "${INSTALLLOGFILE}2" | egrep '\(./.\)'
RETVAL1=$?
if [ $RETVAL1 -ne 0 ]; then
	which $JAVA  > /dev/null
	RETVAL2=$?
	echo ""
	if [ $RETVAL2 -ne 0 ]; then
		echo "$JAVA not found."
		echo "The Java runtime does not seem to be installed or $JAVA is not on the search path."
		echo "$JAVA not found." >> "$INSTALLLOGFILE"
		echo "The Java runtime does not seem to be installed or $JAVA is not on the search path." >> "$INSTALLLOGFILE"
	else
		echo "The installer failed (code $RETVAL1)."
		echo "Check log file $INSTALLLOGFILE for details."
		echo "The installer failed (code $RETVAL1)." >> "$INSTALLLOGFILE"
	fi
	echo "Installation cancelled"
	echo ""
	echo "Installation cancelled" >> "$INSTALLLOGFILE"
	echo "" >> "$INSTALLLOGFILE"
	exit 1
fi


# Consolidate individual logs into $INSTALLLOGFILE and remove individual logs
(
	echo ""
	echo ""
	echo "Installer log:"
	echo "----------------------------------------------------------------"
	cat ${INSTALLLOGFILE}2
	echo "----------------------------------------------------------------"

	echo ""
	echo ""
	echo "Installer warnings and errors:"
	echo "----------------------------------------------------------------"
	cat izpack.log
	echo "----------------------------------------------------------------"

	echo ""
	echo ""
	echo "setup-CAInnovaphone log:"
	echo "----------------------------------------------------------------"
	cat setup-CAInnovaphone.log
	echo "----------------------------------------------------------------"
	echo ""
	echo ""
) >> "$INSTALLLOGFILE"

rm -f ${INSTALLLOGFILE}2
rm -f izpack.log
rm -f setup-CAInnovaphone.log


# Remove installer configuration file that was generated above
echo; echo; echo "Removing configuration file $INSTALLCONFIG"
( echo; echo; echo "Removing configuration file $INSTALLCONFIG" ) >> "$INSTALLLOGFILE"
rm -f $INSTALLCONFIG


echo; echo; echo "NOTE: The service has been installed but has not yet been started"
( echo; echo; echo "NOTE: The service has been installed but has not yet been started"; echo; echo ) >> "$INSTALLLOGFILE"


echo; echo; echo "Generated installer log file:"
echo "> ls -l \"$INSTALLLOGFILE\""
ls -l "$INSTALLLOGFILE"
echo

